<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       
 * @since      1.0
 *
 * @package    Panoee
 * @subpackage Panoee/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Panoee
 * @subpackage Panoee/admin
 * @author     Wordpress plugin <wordpress@gmail.com>
 */
class Panoee_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0
	 * @access   private
	 * @var      string $plugin_name The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0
	 * @access   private
	 * @var      string $version The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0
	 *
	 * @param      string $plugin_name The name of this plugin.
	 * @param      string $version The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Panoee_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Panoee_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'css/panoee-admin.css',
			array(),
			$this->version,
			'all'
		);

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Panoee_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Panoee_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'js/panoee-admin.js',
			array( 'jquery', 'jquery-ui-core', 'jquery-ui-sortable' ),
			$this->version,
			false
		);

	}

	/**
	 * Flush Rewrite Rules after saving plugin options
	 *
	 * @since   2.0
	 */
	public function ajax_flush_rewrite_rules() {

		flush_rewrite_rules();

		wp_send_json_success();

	}

	/**
	 * Register admin menu items.
	 *
	 * @since   1.0
	 */
	public function register_menu() {
		// Generate Theme Options Page
		add_menu_page('Panoee Project', 'Panoee Project', 'manage_options', 'panoee-setting', array( $this, 'panoee_page'), 'dashicons-admin-page', 110);
		// Generate Theme Options Sub Pages
		add_submenu_page('panoee-setting', 'Panoee Project Setting', 'Setting', 'manage_options', 'panoee-setting', array( $this, 'panoee_page') );
		// Setting page.
		add_submenu_page(
			'panoee-setting',
			__( 'Panoee Setting', $this->plugin_name ),
			__( 'Projects', $this->plugin_name ),
			'manage_options',
			'panoee-project',
			array( $this, 'display_project' )
		);

	}


	/**
	 * Display Usage page content.
	 *
	 * @since   1.0
	 */
	public function display_project() {
		$Display_Project = new Panoee_Display_Project();
		echo '<div class="wrap"><h1 class="wp-heading-inline">
		Panoee Project </h1>';
		echo '&nbsp;<a class="page-title-action" href="https://studio.panoee.com/dashboard/projects?openDialogCreateProject=true" target="_blank">Create Project</a></div>';
		$Display_Project->views();
		$Display_Project->prepare_items(); 
		?>
		<form method="post">
			<input type="hidden" name="page" value="" />
			<?php $Display_Project->search_box('search', 'search_post'); ?>
		</form>
		<?php
		$Display_Project->display(); 
		echo '</div>';
		echo '<script>';
		echo 'jQuery( ".wp-list-table" ).removeClass( "fixed" )';
		echo '</script>';
		
	}

	public function panoee_page () {
		

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}
		//Get the active tab from the $_GET param
		$default_tab = null;
		$tab = isset($_GET['tab']) ? $_GET['tab'] : $default_tab;
	  
		?>
		<!-- Our admin page content should all be inside .wrap -->
		<div class="wrap">
		  <!-- Print the page title -->
		  <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
		  <!-- Here are our tabs -->
		  <nav class="nav-tab-wrapper">
			<a href="?page=panoee-setting" class="nav-tab <?php if($tab===null):?>nav-tab-active<?php endif; ?>">General</a>
		  </nav>
	  
		  <div class="tab-content">
		  <?php 
		 	switch($tab) :
			default:
				include_once 'partials/class-panoee-setting-display.php';
				break;
			endswitch; ?>
		  </div>
		</div>
		<?php
	}

}
