<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       
 * @since      1.0
 *
 * @package    Panoee
 * @subpackage Panoee/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Panoee
 * @subpackage Panoee/public
 * @author     Wordpress plugin <wordpress@gmail.com>
 */
class Panoee_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0
	 * @access   private
	 * @var      string $plugin_name The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0
	 * @access   private
	 * @var      string $version The current version of this plugin.
	 */
	private $version;

	/**
	 * The default attributes for the shortcode
	 *
	 * @since  1.0
	 * @access  private
	 * @var array $Panoee_shortcode_atts Attributes passed in with the shortcode.
	 */
	private $Panoee_shortcode_atts;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0
	 * @param    string $plugin_name       The name of the plugin.
	 * @param    string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name                               = $plugin_name;
		$this->version                                   = $version;
		$this->Panoee_shortcode_atts          = array();
		$this->Panoee_shortcode_atts_defaults = array(
			'id'         => '',
			'group'      => '',
			'wrap_class' => '',
			'order'      => 'ASC',
			'image_size' => 'full',
		);

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0
	 */
	public function enqueue_styles() {


		wp_enqueue_style(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'css/panoee-public.css',
			array(),
			$this->version,
			'all'
		);

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'js/panoee-public.js',
			array( 'jquery', 'jquery-ui-core', 'jquery-ui-sortable' ),
			array(), $this->version, true 
		);
	}

	/**
	 * Initialize panoee project custom post type and taxonomies.
	 *
	 * @since 1.0
	 */
	public function panoee_init() {
		
	}


}
